Annual number of catch per positive set on FOB-associated and free-swimming schools.

catch_per_positive_set(
  dataframe,
  fishing_type,
  graph_type = "plot",
  title = FALSE
)

Arguments

dataframe

data.frame expected. 'Csv' or 'output' of the function data_extraction, which must be done before using the query named "balbaya_catch_effort.sql".

fishing_type

character expected. 'FOB' and 'FSC'.

graph_type

character expected. 'plot', 'plotly' or 'table'. Plot by default.

title

TRUE or FALSE expected. Title for plotly graph_type. False by default.

Value

The function return ggplot R plot.

Details

The input dataframe must contain all these columns for the function to work [see referentials]:

Dataframe:


   activity_date | species_code | school_type | set_duration | positive_set | total_set | total_catch_weight | total_hour_fished
   -------------------------------------------------------------------------------------------------------------------------------
   1999-07-09    | 2            | FOB         | 3.54         | 1            | 1         | 119.0              | 12.1
   1999-07-09    | 1            | FOB         | 3.54         | 1            | 1         | 20.6               | 12.1
   1999-07-09    | 1            | FOB         | 3.54         | 1            | 1         | 24.4               | 12.1

Add these columns for an automatic title (optional):

  • country_code

  • ocean_code

  • vessel_type_code