R/catch_per_searching_day.R
catch_per_searching_day.RdAnnual catch rates (in t per searching day) on FOB- associated and free-swimming tuna schools (FSC).
catch_per_searching_day(
dataframe,
fishing_type,
graph_type = "plot",
title = FALSE
)data.frame expected. 'Csv' or 'output' of the function data_extraction, which must be done before using the query named "balbaya_catch_effort.sql".
character expected. 'FOB' or 'FSC'.
character expected. 'plot', 'plotly' or 'table.' Plot by default.
TRUE or FALSE expected. Title for plotly graph_type. False by default.
The function return ggplot R plot.
The input dataframe must contain all these columns for the function to work [see referentials]: Dataframe :
activity_date | species_code | school_type | set_duration | positive_set | total_set | total_catch_weight | total_hour_fished
-------------------------------------------------------------------------------------------------------------------------------
1999-07-09 | 2 | FOB | 3.54 | 1 | 1 | 119.0 | 12.1
1999-07-09 | 1 | FOB | 3.54 | 1 | 1 | 20.6 | 12.1
1999-07-09 | 1 | FOB | 3.54 | 1 | 1 | 24.4 | 12.1Add these columns for an automatic title (optional):
country_code
ocean_code
vessel_type_code